package javax.swing.plaf.basic;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import sun.swing.UIAction;
import java.beans.PropertyChangeEvent;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JViewport;
import java.awt.Point;
import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.BoundedRangeModel;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseAdapter;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.awt.Container;
import java.awt.Component;
import sun.swing.SwingUtilities2;
import java.awt.Insets;
import java.awt.Graphics;
import sun.swing.DefaultLookup;
import javax.swing.InputMap;
import javax.swing.SwingUtilities;
import javax.swing.plaf.UIResource;
import javax.swing.UIManager;
import javax.swing.LookAndFeel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.Timer;
import java.beans.PropertyChangeListener;
import java.awt.Rectangle;
import javax.swing.JButton;
import javax.swing.JScrollBar;
import java.awt.Color;
import java.awt.Dimension;
import javax.swing.SwingConstants;
import java.awt.LayoutManager;
import javax.swing.plaf.ScrollBarUI;

public class BasicScrollBarUI extends ScrollBarUI implements LayoutManager, SwingConstants
{
    private static final int POSITIVE_SCROLL = 1;
    private static final int NEGATIVE_SCROLL = -1;
    private static final int MIN_SCROLL = 2;
    private static final int MAX_SCROLL = 3;
    protected Dimension minimumThumbSize;
    protected Dimension maximumThumbSize;
    protected Color thumbHighlightColor;
    protected Color thumbLightShadowColor;
    protected Color thumbDarkShadowColor;
    protected Color thumbColor;
    protected Color trackColor;
    protected Color trackHighlightColor;
    protected JScrollBar scrollbar;
    protected JButton incrButton;
    protected JButton decrButton;
    protected boolean isDragging;
    protected BasicScrollBarUI.TrackListener trackListener;
    protected BasicScrollBarUI.ArrowButtonListener buttonListener;
    protected BasicScrollBarUI.ModelListener modelListener;
    protected Rectangle thumbRect;
    protected Rectangle trackRect;
    protected int trackHighlight;
    protected static final int NO_HIGHLIGHT = 0;
    protected static final int DECREASE_HIGHLIGHT = 1;
    protected static final int INCREASE_HIGHLIGHT = 2;
    protected BasicScrollBarUI.ScrollListener scrollListener;
    protected PropertyChangeListener propertyChangeListener;
    protected Timer scrollTimer;
    private static final int scrollSpeedThrottle = 60;
    private boolean supportsAbsolutePositioning;
    protected int scrollBarWidth;
    private BasicScrollBarUI.Handler handler;
    private boolean thumbActive;
    private boolean useCachedValue;
    private int scrollBarValue;
    protected int incrGap;
    protected int decrGap;
    
    public BasicScrollBarUI() {
        this.useCachedValue = false;
    }
    
    static void loadActionMap(LazyActionMap lazyActionMap) {
        lazyActionMap.put(new BasicScrollBarUI.Actions("positiveUnitIncrement"));
        lazyActionMap.put(new BasicScrollBarUI.Actions("positiveBlockIncrement"));
        lazyActionMap.put(new BasicScrollBarUI.Actions("negativeUnitIncrement"));
        lazyActionMap.put(new BasicScrollBarUI.Actions("negativeBlockIncrement"));
        lazyActionMap.put(new BasicScrollBarUI.Actions("minScroll"));
        lazyActionMap.put(new BasicScrollBarUI.Actions("maxScroll"));
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new BasicScrollBarUI();
    }
    
    protected void configureScrollBarColors() {
        LookAndFeel.installColors(this.scrollbar, "ScrollBar.background", "ScrollBar.foreground");
        this.thumbHighlightColor = UIManager.getColor("ScrollBar.thumbHighlight");
        this.thumbLightShadowColor = UIManager.getColor("ScrollBar.thumbShadow");
        this.thumbDarkShadowColor = UIManager.getColor("ScrollBar.thumbDarkShadow");
        this.thumbColor = UIManager.getColor("ScrollBar.thumb");
        this.trackColor = UIManager.getColor("ScrollBar.track");
        this.trackHighlightColor = UIManager.getColor("ScrollBar.trackHighlight");
    }
    
    @Override
    public void installUI(JComponent component) {
        this.scrollbar = (JScrollBar)component;
        this.thumbRect = new Rectangle(0, 0, 0, 0);
        this.trackRect = new Rectangle(0, 0, 0, 0);
        this.installDefaults();
        this.installComponents();
        this.installListeners();
        this.installKeyboardActions();
    }
    
    @Override
    public void uninstallUI(JComponent component) {
        this.scrollbar = (JScrollBar)component;
        this.uninstallListeners();
        this.uninstallDefaults();
        this.uninstallComponents();
        this.uninstallKeyboardActions();
        this.thumbRect = null;
        this.scrollbar = null;
        this.incrButton = null;
        this.decrButton = null;
    }
    
    protected void installDefaults() {
        this.scrollBarWidth = UIManager.getInt("ScrollBar.width");
        if (this.scrollBarWidth <= 0) {
            this.scrollBarWidth = 16;
        }
        this.minimumThumbSize = (Dimension)UIManager.get("ScrollBar.minimumThumbSize");
        this.maximumThumbSize = (Dimension)UIManager.get("ScrollBar.maximumThumbSize");
        Boolean b = (Boolean)UIManager.get("ScrollBar.allowsAbsolutePositioning");
        this.supportsAbsolutePositioning = (b != null && (boolean)b);
        this.trackHighlight = 0;
        if (this.scrollbar.getLayout() == null || this.scrollbar.getLayout() instanceof UIResource) {
            this.scrollbar.setLayout(this);
        }
        this.configureScrollBarColors();
        LookAndFeel.installBorder(this.scrollbar, "ScrollBar.border");
        LookAndFeel.installProperty(this.scrollbar, "opaque", Boolean.TRUE);
        this.scrollBarValue = this.scrollbar.getValue();
        this.incrGap = UIManager.getInt("ScrollBar.incrementButtonGap");
        this.decrGap = UIManager.getInt("ScrollBar.decrementButtonGap");
        String anObject = (String)this.scrollbar.getClientProperty("JComponent.sizeVariant");
        if (anObject != null) {
            if ("large".equals(anObject)) {
                this.scrollBarWidth = (int)((double)this.scrollBarWidth * 1.15);
                this.incrGap = (int)((double)this.incrGap * 1.15);
                this.decrGap = (int)((double)this.decrGap * 1.15);
            }
            else if ("small".equals(anObject)) {
                this.scrollBarWidth = (int)((double)this.scrollBarWidth * 0.857);
                this.incrGap = (int)((double)this.incrGap * 0.857);
                this.decrGap = (int)((double)this.decrGap * 0.714);
            }
            else if ("mini".equals(anObject)) {
                this.scrollBarWidth = (int)((double)this.scrollBarWidth * 0.714);
                this.incrGap = (int)((double)this.incrGap * 0.714);
                this.decrGap = (int)((double)this.decrGap * 0.714);
            }
        }
    }
    
    protected void installComponents() {
        switch (this.scrollbar.getOrientation()) {
            case 1: {
                this.incrButton = this.createIncreaseButton(5);
                this.decrButton = this.createDecreaseButton(1);
                break;
            }
            case 0: {
                if (this.scrollbar.getComponentOrientation().isLeftToRight()) {
                    this.incrButton = this.createIncreaseButton(3);
                    this.decrButton = this.createDecreaseButton(7);
                    break;
                }
                this.incrButton = this.createIncreaseButton(7);
                this.decrButton = this.createDecreaseButton(3);
                break;
            }
        }
        this.scrollbar.add(this.incrButton);
        this.scrollbar.add(this.decrButton);
        this.scrollbar.setEnabled(this.scrollbar.isEnabled());
    }
    
    protected void uninstallComponents() {
        this.scrollbar.remove(this.incrButton);
        this.scrollbar.remove(this.decrButton);
    }
    
    protected void installListeners() {
        this.trackListener = this.createTrackListener();
        this.buttonListener = this.createArrowButtonListener();
        this.modelListener = this.createModelListener();
        this.propertyChangeListener = this.createPropertyChangeListener();
        this.scrollbar.addMouseListener(this.trackListener);
        this.scrollbar.addMouseMotionListener(this.trackListener);
        this.scrollbar.getModel().addChangeListener(this.modelListener);
        this.scrollbar.addPropertyChangeListener(this.propertyChangeListener);
        this.scrollbar.addFocusListener(this.getHandler());
        if (this.incrButton != null) {
            this.incrButton.addMouseListener(this.buttonListener);
        }
        if (this.decrButton != null) {
            this.decrButton.addMouseListener(this.buttonListener);
        }
        this.scrollListener = this.createScrollListener();
        (this.scrollTimer = new Timer(60, this.scrollListener)).setInitialDelay(300);
    }
    
    protected void installKeyboardActions() {
        LazyActionMap.installLazyActionMap(this.scrollbar, BasicScrollBarUI.class, "ScrollBar.actionMap");
        SwingUtilities.replaceUIInputMap(this.scrollbar, 0, this.getInputMap(0));
        SwingUtilities.replaceUIInputMap(this.scrollbar, 1, this.getInputMap(1));
    }
    
    protected void uninstallKeyboardActions() {
        SwingUtilities.replaceUIInputMap(this.scrollbar, 0, null);
        SwingUtilities.replaceUIActionMap(this.scrollbar, null);
    }
    
    private InputMap getInputMap(int n) {
        if (n == 0) {
            InputMap parent2 = (InputMap)DefaultLookup.get(this.scrollbar, this, "ScrollBar.focusInputMap");
            InputMap inputMap2;
            if (this.scrollbar.getComponentOrientation().isLeftToRight() || (inputMap2 = (InputMap)DefaultLookup.get(this.scrollbar, this, "ScrollBar.focusInputMap.RightToLeft")) == null) {
                return parent2;
            }
            inputMap2.setParent(parent2);
            return inputMap2;
        }
        else if (n == 1) {
            InputMap parent = (InputMap)DefaultLookup.get(this.scrollbar, this, "ScrollBar.ancestorInputMap");
            InputMap inputMap;
            if (this.scrollbar.getComponentOrientation().isLeftToRight() || (inputMap = (InputMap)DefaultLookup.get(this.scrollbar, this, "ScrollBar.ancestorInputMap.RightToLeft")) == null) {
                return parent;
            }
            inputMap.setParent(parent);
            return inputMap;
        }
        else {
            return null;
        }
    }
    
    protected void uninstallListeners() {
        this.scrollTimer.stop();
        this.scrollTimer = null;
        if (this.decrButton != null) {
            this.decrButton.removeMouseListener(this.buttonListener);
        }
        if (this.incrButton != null) {
            this.incrButton.removeMouseListener(this.buttonListener);
        }
        this.scrollbar.getModel().removeChangeListener(this.modelListener);
        this.scrollbar.removeMouseListener(this.trackListener);
        this.scrollbar.removeMouseMotionListener(this.trackListener);
        this.scrollbar.removePropertyChangeListener(this.propertyChangeListener);
        this.scrollbar.removeFocusListener(this.getHandler());
        this.handler = null;
    }
    
    protected void uninstallDefaults() {
        LookAndFeel.uninstallBorder(this.scrollbar);
        if (this.scrollbar.getLayout() == this) {
            this.scrollbar.setLayout(null);
        }
    }
    
    private BasicScrollBarUI.Handler getHandler() {
        if (this.handler == null) {
            this.handler = new BasicScrollBarUI.Handler();
        }
        return this.handler;
    }
    
    protected BasicScrollBarUI.TrackListener createTrackListener() {
        return new BasicScrollBarUI.TrackListener();
    }
    
    protected BasicScrollBarUI.ArrowButtonListener createArrowButtonListener() {
        return new BasicScrollBarUI.ArrowButtonListener();
    }
    
    protected BasicScrollBarUI.ModelListener createModelListener() {
        return new BasicScrollBarUI.ModelListener();
    }
    
    protected BasicScrollBarUI.ScrollListener createScrollListener() {
        return new BasicScrollBarUI.ScrollListener();
    }
    
    protected PropertyChangeListener createPropertyChangeListener() {
        return this.getHandler();
    }
    
    private void updateThumbState(int x, int y) {
        this.setThumbRollover(this.getThumbBounds().contains(x, y));
    }
    
    protected void setThumbRollover(boolean thumbActive) {
        if (this.thumbActive != thumbActive) {
            this.thumbActive = thumbActive;
            this.scrollbar.repaint(this.getThumbBounds());
        }
    }
    
    public boolean isThumbRollover() {
        return this.thumbActive;
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        this.paintTrack(graphics, component, this.getTrackBounds());
        Rectangle thumbBounds = this.getThumbBounds();
        if (thumbBounds.intersects(graphics.getClipBounds())) {
            this.paintThumb(graphics, component, thumbBounds);
        }
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        return (this.scrollbar.getOrientation() == 1) ? new Dimension(this.scrollBarWidth, 48) : new Dimension(48, this.scrollBarWidth);
    }
    
    @Override
    public Dimension getMaximumSize(JComponent component) {
        return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
    }
    
    protected JButton createDecreaseButton(int n) {
        return new BasicArrowButton(n, UIManager.getColor("ScrollBar.thumb"), UIManager.getColor("ScrollBar.thumbShadow"), UIManager.getColor("ScrollBar.thumbDarkShadow"), UIManager.getColor("ScrollBar.thumbHighlight"));
    }
    
    protected JButton createIncreaseButton(int n) {
        return new BasicArrowButton(n, UIManager.getColor("ScrollBar.thumb"), UIManager.getColor("ScrollBar.thumbShadow"), UIManager.getColor("ScrollBar.thumbDarkShadow"), UIManager.getColor("ScrollBar.thumbHighlight"));
    }
    
    protected void paintDecreaseHighlight(Graphics graphics) {
        Insets insets = this.scrollbar.getInsets();
        Rectangle thumbBounds = this.getThumbBounds();
        graphics.setColor(this.trackHighlightColor);
        if (this.scrollbar.getOrientation() == 1) {
            int left = insets.left;
            int y = this.trackRect.y;
            graphics.fillRect(left, y, this.scrollbar.getWidth() - (insets.left + insets.right), thumbBounds.y - y);
        }
        else {
            int x;
            int n;
            if (this.scrollbar.getComponentOrientation().isLeftToRight()) {
                x = this.trackRect.x;
                n = thumbBounds.x - x;
            }
            else {
                x = thumbBounds.x + thumbBounds.width;
                n = this.trackRect.x + this.trackRect.width - x;
            }
            graphics.fillRect(x, insets.top, n, this.scrollbar.getHeight() - (insets.top + insets.bottom));
        }
    }
    
    protected void paintIncreaseHighlight(Graphics graphics) {
        Insets insets = this.scrollbar.getInsets();
        Rectangle thumbBounds = this.getThumbBounds();
        graphics.setColor(this.trackHighlightColor);
        if (this.scrollbar.getOrientation() == 1) {
            int left = insets.left;
            int n2 = thumbBounds.y + thumbBounds.height;
            graphics.fillRect(left, n2, this.scrollbar.getWidth() - (insets.left + insets.right), this.trackRect.y + this.trackRect.height - n2);
        }
        else {
            int x;
            int n;
            if (this.scrollbar.getComponentOrientation().isLeftToRight()) {
                x = thumbBounds.x + thumbBounds.width;
                n = this.trackRect.x + this.trackRect.width - x;
            }
            else {
                x = this.trackRect.x;
                n = thumbBounds.x - x;
            }
            graphics.fillRect(x, insets.top, n, this.scrollbar.getHeight() - (insets.top + insets.bottom));
        }
    }
    
    protected void paintTrack(Graphics graphics, JComponent component, Rectangle rectangle) {
        graphics.setColor(this.trackColor);
        graphics.fillRect(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
        if (this.trackHighlight == 1) {
            this.paintDecreaseHighlight(graphics);
        }
        else if (this.trackHighlight == 2) {
            this.paintIncreaseHighlight(graphics);
        }
    }
    
    protected void paintThumb(Graphics g, JComponent component, Rectangle rectangle) {
        if (rectangle.isEmpty() || !this.scrollbar.isEnabled()) {
            return;
        }
        int width = rectangle.width;
        int height = rectangle.height;
        g.translate(rectangle.x, rectangle.y);
        g.setColor(this.thumbDarkShadowColor);
        SwingUtilities2.drawRect(g, 0, 0, width - 1, height - 1);
        g.setColor(this.thumbColor);
        g.fillRect(0, 0, width - 1, height - 1);
        g.setColor(this.thumbHighlightColor);
        SwingUtilities2.drawVLine(g, 1, 1, height - 2);
        SwingUtilities2.drawHLine(g, 2, width - 3, 1);
        g.setColor(this.thumbLightShadowColor);
        SwingUtilities2.drawHLine(g, 2, width - 2, height - 2);
        SwingUtilities2.drawVLine(g, width - 2, 1, height - 3);
        g.translate(-rectangle.x, -rectangle.y);
        return;
    }
    
    protected Dimension getMinimumThumbSize() {
        return this.minimumThumbSize;
    }
    
    protected Dimension getMaximumThumbSize() {
        return this.maximumThumbSize;
    }
    
    @Override
    public void addLayoutComponent(String s, Component component) {
    }
    
    @Override
    public void removeLayoutComponent(Component component) {
    }
    
    @Override
    public Dimension preferredLayoutSize(Container container) {
        return this.getPreferredSize((JComponent)container);
    }
    
    @Override
    public Dimension minimumLayoutSize(Container container) {
        return this.getMinimumSize((JComponent)container);
    }
    
    private int getValue(JScrollBar scrollBar) {
        return this.useCachedValue ? this.scrollBarValue : scrollBar.getValue();
    }
    
    protected void layoutVScrollbar(JScrollBar scrollBar) {
        Dimension size = scrollBar.getSize();
        Insets insets = scrollBar.getInsets();
        int width = size.width - (insets.left + insets.right);
        int left = insets.left;
        int boolean1 = DefaultLookup.getBoolean(this.scrollbar, this, "ScrollBar.squareButtons", false);
        int height = boolean1 ? width : this.decrButton.getPreferredSize().height;
        int top = insets.top;
        int height2 = boolean1 ? width : this.incrButton.getPreferredSize().height;
        int y = size.height - (insets.bottom + height2);
        int n = insets.top + insets.bottom;
        int n2 = height + height2;
        float n3 = (float)(size.height - (n + n2) - (this.decrGap + this.incrGap));
        float n4 = (float)scrollBar.getMinimum();
        float n5 = (float)scrollBar.getVisibleAmount();
        float n6 = (float)scrollBar.getMaximum() - n4;
        float n7 = (float)this.getValue(scrollBar);
        int min = Math.min(Math.max((n6 <= 0.0f) ? this.getMaximumThumbSize().height : ((int)(n3 * (n5 / n6))), this.getMinimumThumbSize().height), this.getMaximumThumbSize().height);
        int n8 = y - this.incrGap - min;
        if (n7 < (float)(scrollBar.getMaximum() - scrollBar.getVisibleAmount())) {
            n8 = (int)(0.5f + (n3 - (float)min) * ((n7 - n4) / (n6 - n5))) + (top + height + this.decrGap);
        }
        int n9 = size.height - n;
        if (n9 < n2) {
            height = (height2 = n9 / 2);
            y = size.height - (insets.bottom + height2);
        }
        this.decrButton.setBounds(left, top, width, height);
        this.incrButton.setBounds(left, y, width, height2);
        int y2 = top + height + this.decrGap;
        int height3 = y - this.incrGap - y2;
        this.trackRect.setBounds(left, y2, width, height3);
        if (min >= (int)n3) {
            if (UIManager.getBoolean("ScrollBar.alwaysShowThumb")) {
                this.setThumbBounds(left, y2, width, height3);
            }
            else {
                this.setThumbBounds(0, 0, 0, 0);
            }
        }
        else {
            if (n8 + min > y - this.incrGap) {
                n8 = y - this.incrGap - min;
            }
            if (n8 < top + height + this.decrGap) {
                n8 = top + height + this.decrGap + 1;
            }
            this.setThumbBounds(left, n8, width, min);
        }
    }
    
    protected void layoutHScrollbar(JScrollBar scrollBar) {
        Dimension size = scrollBar.getSize();
        Insets insets = scrollBar.getInsets();
        int height = size.height - (insets.top + insets.bottom);
        int top = insets.top;
        int leftToRight = scrollBar.getComponentOrientation().isLeftToRight();
        int boolean1 = DefaultLookup.getBoolean(this.scrollbar, this, "ScrollBar.squareButtons", false);
        int width = boolean1 ? height : this.decrButton.getPreferredSize().width;
        int width2 = boolean1 ? height : this.incrButton.getPreferredSize().width;
        if (leftToRight == 0) {
            width = (width2 = width2);
        }
        int left = insets.left;
        int x = size.width - (insets.right + width2);
        int n = leftToRight ? this.decrGap : this.incrGap;
        int n2 = leftToRight ? this.incrGap : this.decrGap;
        int n3 = insets.left + insets.right;
        int n4 = width + width2;
        float n5 = (float)(size.width - (n3 + n4) - (n + n2));
        float n6 = (float)scrollBar.getMinimum();
        float n7 = (float)scrollBar.getMaximum();
        float n8 = (float)scrollBar.getVisibleAmount();
        float n9 = n7 - n6;
        float n10 = (float)this.getValue(scrollBar);
        int min = Math.min(Math.max((n9 <= 0.0f) ? this.getMaximumThumbSize().width : ((int)(n5 * (n8 / n9))), this.getMinimumThumbSize().width), this.getMaximumThumbSize().width);
        int n11 = leftToRight ? (x - n2 - min) : (left + width + n);
        if (n10 < n7 - (float)scrollBar.getVisibleAmount()) {
            float n12 = n5 - (float)min;
            int n13;
            if (!(leftToRight == 0)) {
                n13 = (int)(0.5f + n12 * ((n10 - n6) / (n9 - n8)));
            }
            else {
                n13 = (int)(0.5f + n12 * ((n7 - n8 - n10) / (n9 - n8)));
            }
            n11 = n13 + (left + width + n);
        }
        int n14 = size.width - n3;
        if (n14 < n4) {
            width = (width2 = n14 / 2);
            x = size.width - (insets.right + width2 + n2);
        }
        (leftToRight ? this.decrButton : this.incrButton).setBounds(left, top, width, height);
        (leftToRight ? this.incrButton : this.decrButton).setBounds(x, top, width2, height);
        int x2 = left + width + n;
        int width3 = x - n2 - x2;
        this.trackRect.setBounds(x2, top, width3, height);
        if (min >= (int)n5) {
            if (UIManager.getBoolean("ScrollBar.alwaysShowThumb")) {
                this.setThumbBounds(x2, top, width3, height);
            }
            else {
                this.setThumbBounds(0, 0, 0, 0);
            }
        }
        else {
            if (n11 + min > x - n2) {
                n11 = x - n2 - min;
            }
            if (n11 < left + width + n) {
                n11 = left + width + n + 1;
            }
            this.setThumbBounds(n11, top, min, height);
        }
    }
    
    @Override
    public void layoutContainer(Container container) {
        if (this.isDragging) {
            return;
        }
        JScrollBar scrollBar = (JScrollBar)container;
        switch (scrollBar.getOrientation()) {
            case 1: {
                this.layoutVScrollbar(scrollBar);
                break;
            }
            case 0: {
                this.layoutHScrollbar(scrollBar);
                break;
            }
        }
        return;
    }
    
    protected void setThumbBounds(int n, int n2, int width, int height) {
        if (this.thumbRect.x == n && this.thumbRect.y == n2 && this.thumbRect.width == width && this.thumbRect.height == height) {
            return;
        }
        int min = Math.min(n, this.thumbRect.x);
        int min2 = Math.min(n2, this.thumbRect.y);
        int max = Math.max(n + width, this.thumbRect.x + this.thumbRect.width);
        int max2 = Math.max(n2 + height, this.thumbRect.y + this.thumbRect.height);
        this.thumbRect.setBounds(n, n2, width, height);
        this.scrollbar.repaint(min, min2, max - min, max2 - min2);
        this.setThumbRollover(false);
        return;
    }
    
    protected Rectangle getThumbBounds() {
        return this.thumbRect;
    }
    
    protected Rectangle getTrackBounds() {
        return this.trackRect;
    }
    
    static void scrollByBlock(JScrollBar scrollBar, int direction) {
        int value = scrollBar.getValue();
        int n = scrollBar.getBlockIncrement(direction) * ((direction > 0) ? 1 : -1);
        int value2 = value + n;
        if (n > 0 && value2 < value) {
            value2 = scrollBar.getMaximum();
        }
        else if (n < 0 && value2 > value) {
            value2 = scrollBar.getMinimum();
        }
        scrollBar.setValue(value2);
    }
    
    protected void scrollByBlock(int n) {
        scrollByBlock(this.scrollbar, n);
        this.trackHighlight = ((n > 0) ? 2 : 1);
        Rectangle trackBounds = this.getTrackBounds();
        this.scrollbar.repaint(trackBounds.x, trackBounds.y, trackBounds.width, trackBounds.height);
    }
    
    static void scrollByUnits(JScrollBar scrollBar, int n, int n2, boolean b) {
        int n3 = -1;
        if (b) {
            if (n < 0) {
                n3 = scrollBar.getValue() - scrollBar.getBlockIncrement(n);
            }
            else {
                n3 = scrollBar.getValue() + scrollBar.getBlockIncrement(n);
            }
        }
        int i = 0;
        while (i < n2) {
            int unitIncrement;
            if (n > 0) {
                unitIncrement = scrollBar.getUnitIncrement(n);
            }
            else {
                unitIncrement = -scrollBar.getUnitIncrement(n);
            }
            int value = scrollBar.getValue();
            int value2 = value + unitIncrement;
            if (unitIncrement > 0 && value2 < value) {
                value2 = scrollBar.getMaximum();
            }
            else if (unitIncrement < 0 && value2 > value) {
                value2 = scrollBar.getMinimum();
            }
            if (value == value2) {
                break;
            }
            if (b && i > 0) {
                assert n3 != -1;
                if (n >= 0 || value2 >= n3) {
                    if (n > 0 && value2 > n3) {
                        break;
                    }
                }
                else {
                    break;
                }
            }
            scrollBar.setValue(value2);
            ++i;
        }
    }
    
    protected void scrollByUnit(int n) {
        scrollByUnits(this.scrollbar, n, 1, false);
    }
    
    public boolean getSupportsAbsolutePositioning() {
        return this.supportsAbsolutePositioning;
    }
    
    private boolean isMouseLeftOfThumb() {
        return this.trackListener.currentMouseX < this.getThumbBounds().x;
    }
    
    private boolean isMouseRightOfThumb() {
        Rectangle thumbBounds = this.getThumbBounds();
        return this.trackListener.currentMouseX > thumbBounds.x + thumbBounds.width;
    }
    
    private boolean isMouseBeforeThumb() {
        return this.scrollbar.getComponentOrientation().isLeftToRight() ? this.isMouseLeftOfThumb() : this.isMouseRightOfThumb();
    }
    
    private boolean isMouseAfterThumb() {
        return this.scrollbar.getComponentOrientation().isLeftToRight() ? this.isMouseRightOfThumb() : this.isMouseLeftOfThumb();
    }
    
    private void updateButtonDirections() {
        int orientation = this.scrollbar.getOrientation();
        if (this.scrollbar.getComponentOrientation().isLeftToRight()) {
            if ((this.incrButton instanceof BasicArrowButton)) {
                ((BasicArrowButton)this.incrButton).setDirection((orientation == 0) ? 3 : 5);
            }
            if ((this.decrButton instanceof BasicArrowButton)) {
                ((BasicArrowButton)this.decrButton).setDirection((orientation == 0) ? 7 : 1);
            }
        }
        else {
            if ((this.incrButton instanceof BasicArrowButton)) {
                ((BasicArrowButton)this.incrButton).setDirection((orientation == 0) ? 7 : 5);
            }
            if ((this.decrButton instanceof BasicArrowButton)) {
                ((BasicArrowButton)this.decrButton).setDirection((orientation == 0) ? 3 : 1);
            }
        }
    }
    
    static void access$300(BasicScrollBarUI basicScrollBarUI, int n, int n2) {
        basicScrollBarUI.updateThumbState(n, n2);
    }
    
    static boolean access$400(BasicScrollBarUI basicScrollBarUI) {
        return basicScrollBarUI.isMouseAfterThumb();
    }
    
    static boolean access$500(BasicScrollBarUI basicScrollBarUI) {
        return basicScrollBarUI.isMouseBeforeThumb();
    }
    
    static BasicScrollBarUI.Handler access$600(BasicScrollBarUI basicScrollBarUI) {
        return basicScrollBarUI.getHandler();
    }
    
    static void access$700(BasicScrollBarUI basicScrollBarUI) {
        basicScrollBarUI.updateButtonDirections();
    }
    
    static InputMap access$800(BasicScrollBarUI basicScrollBarUI, int n) {
        return basicScrollBarUI.getInputMap(n);
    }
    
    protected class ModelListener implements ChangeListener
    {
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            if (!BasicScrollBarUI.this.useCachedValue) {
                BasicScrollBarUI.this.scrollBarValue = BasicScrollBarUI.this.scrollbar.getValue();
            }
            BasicScrollBarUI.this.layoutContainer(BasicScrollBarUI.this.scrollbar);
            BasicScrollBarUI.this.useCachedValue = false;
        }
    }
    
    protected class TrackListener extends MouseAdapter implements MouseMotionListener
    {
        protected transient int offset;
        protected transient int currentMouseX;
        protected transient int currentMouseY;
        private transient int direction;
        
        protected TrackListener() {
            this.direction = 1;
        }
        
        @Override
        public void mouseReleased(MouseEvent mouseEvent) {
            if (BasicScrollBarUI.this.isDragging) {
                BasicScrollBarUI.access$300(BasicScrollBarUI.this, mouseEvent.getX(), mouseEvent.getY());
            }
            if (SwingUtilities.isRightMouseButton(mouseEvent) || (!BasicScrollBarUI.this.getSupportsAbsolutePositioning() && SwingUtilities.isMiddleMouseButton(mouseEvent))) {
                return;
            }
            if (!BasicScrollBarUI.this.scrollbar.isEnabled()) {
                return;
            }
            Rectangle trackBounds = BasicScrollBarUI.this.getTrackBounds();
            BasicScrollBarUI.this.scrollbar.repaint(trackBounds.x, trackBounds.y, trackBounds.width, trackBounds.height);
            BasicScrollBarUI.this.trackHighlight = 0;
            BasicScrollBarUI.this.isDragging = false;
            this.offset = 0;
            BasicScrollBarUI.this.scrollTimer.stop();
            BasicScrollBarUI.this.useCachedValue = true;
            BasicScrollBarUI.this.scrollbar.setValueIsAdjusting(false);
            return;
        }
        
        @Override
        public void mousePressed(MouseEvent mouseEvent) {
            if (SwingUtilities.isRightMouseButton(mouseEvent) || (!BasicScrollBarUI.this.getSupportsAbsolutePositioning() && SwingUtilities.isMiddleMouseButton(mouseEvent))) {
                return;
            }
            if (!BasicScrollBarUI.this.scrollbar.isEnabled()) {
                return;
            }
            if (!BasicScrollBarUI.this.scrollbar.hasFocus() && BasicScrollBarUI.this.scrollbar.isRequestFocusEnabled()) {
                BasicScrollBarUI.this.scrollbar.requestFocus();
            }
            BasicScrollBarUI.this.useCachedValue = true;
            BasicScrollBarUI.this.scrollbar.setValueIsAdjusting(true);
            this.currentMouseX = mouseEvent.getX();
            this.currentMouseY = mouseEvent.getY();
            if (BasicScrollBarUI.this.getThumbBounds().contains(this.currentMouseX, this.currentMouseY)) {
                switch (BasicScrollBarUI.this.scrollbar.getOrientation()) {
                    case 1: {
                        this.offset = this.currentMouseY - BasicScrollBarUI.this.getThumbBounds().y;
                        break;
                    }
                    case 0: {
                        this.offset = this.currentMouseX - BasicScrollBarUI.this.getThumbBounds().x;
                        break;
                    }
                }
                BasicScrollBarUI.this.isDragging = true;
                return;
            }
            if (BasicScrollBarUI.this.getSupportsAbsolutePositioning() && SwingUtilities.isMiddleMouseButton(mouseEvent)) {
                switch (BasicScrollBarUI.this.scrollbar.getOrientation()) {
                    case 1: {
                        this.offset = BasicScrollBarUI.this.getThumbBounds().height / 2;
                        break;
                    }
                    case 0: {
                        this.offset = BasicScrollBarUI.this.getThumbBounds().width / 2;
                        break;
                    }
                }
                BasicScrollBarUI.this.isDragging = true;
                this.setValueFrom(mouseEvent);
                return;
            }
            BasicScrollBarUI.this.isDragging = false;
            Dimension size = BasicScrollBarUI.this.scrollbar.getSize();
            this.direction = 1;
            switch (BasicScrollBarUI.this.scrollbar.getOrientation()) {
                case 1: {
                    if (BasicScrollBarUI.this.getThumbBounds().isEmpty()) {
                        this.direction = ((this.currentMouseY < size.height / 2) ? -1 : 1);
                        break;
                    }
                    this.direction = ((this.currentMouseY < BasicScrollBarUI.this.getThumbBounds().y) ? -1 : 1);
                    break;
                }
                case 0: {
                    if (BasicScrollBarUI.this.getThumbBounds().isEmpty()) {
                        this.direction = ((this.currentMouseX < size.width / 2) ? -1 : 1);
                    }
                    else {
                        this.direction = ((this.currentMouseX < BasicScrollBarUI.this.getThumbBounds().x) ? -1 : 1);
                    }
                    if (!BasicScrollBarUI.this.scrollbar.getComponentOrientation().isLeftToRight()) {
                        this.direction = -this.direction;
                        break;
                    }
                    break;
                }
            }
            BasicScrollBarUI.this.scrollByBlock(this.direction);
            BasicScrollBarUI.this.scrollTimer.stop();
            BasicScrollBarUI.this.scrollListener.setDirection(this.direction);
            BasicScrollBarUI.this.scrollListener.setScrollByBlock(true);
            this.startScrollTimerIfNecessary();
            return;
        }
        
        @Override
        public void mouseDragged(MouseEvent valueFrom) {
            if (SwingUtilities.isRightMouseButton(valueFrom) || (!BasicScrollBarUI.this.getSupportsAbsolutePositioning() && SwingUtilities.isMiddleMouseButton(valueFrom))) {
                return;
            }
            if (!BasicScrollBarUI.this.scrollbar.isEnabled() || BasicScrollBarUI.this.getThumbBounds().isEmpty()) {
                return;
            }
            if (BasicScrollBarUI.this.isDragging) {
                this.setValueFrom(valueFrom);
            }
            else {
                this.currentMouseX = valueFrom.getX();
                this.currentMouseY = valueFrom.getY();
                BasicScrollBarUI.access$300(BasicScrollBarUI.this, this.currentMouseX, this.currentMouseY);
                this.startScrollTimerIfNecessary();
            }
            return;
        }
        
        private void setValueFrom(MouseEvent mouseEvent) {
            int thumbRollover = BasicScrollBarUI.this.isThumbRollover();
            BoundedRangeModel model = BasicScrollBarUI.this.scrollbar.getModel();
            Rectangle thumbBounds = BasicScrollBarUI.this.getThumbBounds();
            int n;
            int n2;
            int n3;
            if (BasicScrollBarUI.this.scrollbar.getOrientation() == 1) {
                n = BasicScrollBarUI.this.trackRect.y;
                n2 = BasicScrollBarUI.this.trackRect.y + BasicScrollBarUI.this.trackRect.height - thumbBounds.height;
                n3 = Math.min(n2, Math.max(n, mouseEvent.getY() - this.offset));
                BasicScrollBarUI.this.setThumbBounds(thumbBounds.x, n3, thumbBounds.width, thumbBounds.height);
                float n5 = (float)BasicScrollBarUI.this.getTrackBounds().height;
            }
            else {
                n = BasicScrollBarUI.this.trackRect.x;
                n2 = BasicScrollBarUI.this.trackRect.x + BasicScrollBarUI.this.trackRect.width - thumbBounds.width;
                n3 = Math.min(n2, Math.max(n, mouseEvent.getX() - this.offset));
                BasicScrollBarUI.this.setThumbBounds(n3, thumbBounds.y, thumbBounds.width, thumbBounds.height);
                float n4 = (float)BasicScrollBarUI.this.getTrackBounds().width;
            }
            if (n3 == n2) {
                if (BasicScrollBarUI.this.scrollbar.getOrientation() == 1 || BasicScrollBarUI.this.scrollbar.getComponentOrientation().isLeftToRight()) {
                    BasicScrollBarUI.this.scrollbar.setValue(model.getMaximum() - model.getExtent());
                }
                else {
                    BasicScrollBarUI.this.scrollbar.setValue(model.getMinimum());
                }
            }
            else {
                float n6 = (float)(model.getMaximum() - model.getExtent()) - (float)model.getMinimum();
                float n7 = (float)(n3 - n);
                float n8 = (float)(n2 - n);
                int n9;
                if (BasicScrollBarUI.this.scrollbar.getOrientation() == 1 || BasicScrollBarUI.this.scrollbar.getComponentOrientation().isLeftToRight()) {
                    n9 = (int)(0.5 + (double)(n7 / n8 * n6));
                }
                else {
                    n9 = (int)(0.5 + (double)((float)(n2 - n3) / n8 * n6));
                }
                BasicScrollBarUI.this.useCachedValue = true;
                BasicScrollBarUI.this.scrollBarValue = n9 + model.getMinimum();
                BasicScrollBarUI.this.scrollbar.setValue(this.adjustValueIfNecessary(BasicScrollBarUI.this.scrollBarValue));
            }
            BasicScrollBarUI.this.setThumbRollover((boolean)thumbRollover);
        }
        
        private int adjustValueIfNecessary(int x) {
            if ((BasicScrollBarUI.this.scrollbar.getParent() instanceof JScrollPane)) {
                JScrollPane scrollPane = (JScrollPane)BasicScrollBarUI.this.scrollbar.getParent();
                JViewport viewport = scrollPane.getViewport();
                Component view = viewport.getView();
                if ((view instanceof JList)) {
                    JList<Object> c = (JList)view;
                    if (DefaultLookup.getBoolean(c, c.getUI(), "List.lockToPositionOnScroll", false)) {
                        int layoutOrientation = c.getLayoutOrientation();
                        int orientation = BasicScrollBarUI.this.scrollbar.getOrientation();
                        if (orientation == 1 && layoutOrientation == 0) {
                            int locationToIndex = c.locationToIndex(new Point(0, x));
                            Rectangle cellBounds = c.getCellBounds(locationToIndex, locationToIndex);
                            if (cellBounds != null) {
                                x = cellBounds.y;
                            }
                        }
                        if (orientation == 0 && (layoutOrientation == 1 || layoutOrientation == 2)) {
                            if (scrollPane.getComponentOrientation().isLeftToRight()) {
                                int locationToIndex3 = c.locationToIndex(new Point(x, 0));
                                Rectangle cellBounds3 = c.getCellBounds(locationToIndex3, locationToIndex3);
                                if (cellBounds3 != null) {
                                    x = cellBounds3.x;
                                }
                            }
                            else {
                                Point location = new Point(x, 0);
                                int width = viewport.getExtentSize().width;
                                location.x += width - 1;
                                int locationToIndex2 = c.locationToIndex(location);
                                Rectangle cellBounds2 = c.getCellBounds(locationToIndex2, locationToIndex2);
                                if (cellBounds2 != null) {
                                    x = cellBounds2.x + cellBounds2.width - width;
                                }
                            }
                        }
                    }
                }
            }
            return x;
        }
        
        private void startScrollTimerIfNecessary() {
            if (BasicScrollBarUI.this.scrollTimer.isRunning()) {
                return;
            }
            Rectangle thumbBounds = BasicScrollBarUI.this.getThumbBounds();
            switch (BasicScrollBarUI.this.scrollbar.getOrientation()) {
                case 1: {
                    if (this.direction > 0) {
                        if (thumbBounds.y + thumbBounds.height < BasicScrollBarUI.this.trackListener.currentMouseY) {
                            BasicScrollBarUI.this.scrollTimer.start();
                            break;
                        }
                        break;
                    }
                    else {
                        if (thumbBounds.y > BasicScrollBarUI.this.trackListener.currentMouseY) {
                            BasicScrollBarUI.this.scrollTimer.start();
                            break;
                        }
                        break;
                    }
                }
                case 0: {
                    if ((this.direction > 0 && BasicScrollBarUI.access$400(BasicScrollBarUI.this)) || (this.direction < 0 && BasicScrollBarUI.access$500(BasicScrollBarUI.this))) {
                        BasicScrollBarUI.this.scrollTimer.start();
                        break;
                    }
                    break;
                }
            }
            return;
        }
        
        @Override
        public void mouseMoved(MouseEvent mouseEvent) {
            if (!BasicScrollBarUI.this.isDragging) {
                BasicScrollBarUI.access$300(BasicScrollBarUI.this, mouseEvent.getX(), mouseEvent.getY());
            }
        }
        
        @Override
        public void mouseExited(MouseEvent mouseEvent) {
            if (!BasicScrollBarUI.this.isDragging) {
                BasicScrollBarUI.this.setThumbRollover(false);
            }
        }
    }
    
    protected class ArrowButtonListener extends MouseAdapter
    {
        boolean handledEvent;
        
        @Override
        public void mousePressed(MouseEvent anEvent) {
            if (!BasicScrollBarUI.this.scrollbar.isEnabled()) {
                return;
            }
            if (!SwingUtilities.isLeftMouseButton(anEvent)) {
                return;
            }
            int direction = (anEvent.getSource() == BasicScrollBarUI.this.incrButton) ? 1 : -1;
            BasicScrollBarUI.this.scrollByUnit(direction);
            BasicScrollBarUI.this.scrollTimer.stop();
            BasicScrollBarUI.this.scrollListener.setDirection(direction);
            BasicScrollBarUI.this.scrollListener.setScrollByBlock(false);
            BasicScrollBarUI.this.scrollTimer.start();
            this.handledEvent = true;
            if (!BasicScrollBarUI.this.scrollbar.hasFocus() && BasicScrollBarUI.this.scrollbar.isRequestFocusEnabled()) {
                BasicScrollBarUI.this.scrollbar.requestFocus();
            }
            return;
        }
        
        @Override
        public void mouseReleased(MouseEvent mouseEvent) {
            BasicScrollBarUI.this.scrollTimer.stop();
            this.handledEvent = false;
            BasicScrollBarUI.this.scrollbar.setValueIsAdjusting(false);
        }
    }
    
    protected class ScrollListener implements ActionListener
    {
        int direction;
        boolean useBlockIncrement;
        
        public ScrollListener() {
            this.direction = 1;
            this.direction = 1;
            this.useBlockIncrement = false;
        }
        
        public ScrollListener(int direction, boolean useBlockIncrement) {
            this.direction = 1;
            this.direction = direction;
            this.useBlockIncrement = useBlockIncrement;
        }
        
        public void setDirection(int direction) {
            this.direction = direction;
        }
        
        public void setScrollByBlock(boolean useBlockIncrement) {
            this.useBlockIncrement = useBlockIncrement;
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            if (this.useBlockIncrement) {
                BasicScrollBarUI.this.scrollByBlock(this.direction);
                if (BasicScrollBarUI.this.scrollbar.getOrientation() == 1) {
                    if (this.direction > 0) {
                        if (BasicScrollBarUI.this.getThumbBounds().y + BasicScrollBarUI.this.getThumbBounds().height >= BasicScrollBarUI.this.trackListener.currentMouseY) {
                            ((Timer)actionEvent.getSource()).stop();
                        }
                    }
                    else if (BasicScrollBarUI.this.getThumbBounds().y <= BasicScrollBarUI.this.trackListener.currentMouseY) {
                        ((Timer)actionEvent.getSource()).stop();
                    }
                }
                else if ((this.direction > 0 && !BasicScrollBarUI.access$400(BasicScrollBarUI.this)) || (this.direction < 0 && !BasicScrollBarUI.access$500(BasicScrollBarUI.this))) {
                    ((Timer)actionEvent.getSource()).stop();
                }
            }
            else {
                BasicScrollBarUI.this.scrollByUnit(this.direction);
            }
            if (this.direction > 0 && BasicScrollBarUI.this.scrollbar.getValue() + BasicScrollBarUI.this.scrollbar.getVisibleAmount() >= BasicScrollBarUI.this.scrollbar.getMaximum()) {
                ((Timer)actionEvent.getSource()).stop();
            }
            else if (this.direction < 0 && BasicScrollBarUI.this.scrollbar.getValue() <= BasicScrollBarUI.this.scrollbar.getMinimum()) {
                ((Timer)actionEvent.getSource()).stop();
            }
        }
    }
    
    public class PropertyChangeHandler implements PropertyChangeListener
    {
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            BasicScrollBarUI.access$600(BasicScrollBarUI.this).propertyChange(propertyChangeEvent);
        }
    }
    
    private static class Actions extends UIAction
    {
        private static final String POSITIVE_UNIT_INCREMENT = "positiveUnitIncrement";
        private static final String POSITIVE_BLOCK_INCREMENT = "positiveBlockIncrement";
        private static final String NEGATIVE_UNIT_INCREMENT = "negativeUnitIncrement";
        private static final String NEGATIVE_BLOCK_INCREMENT = "negativeBlockIncrement";
        private static final String MIN_SCROLL = "minScroll";
        private static final String MAX_SCROLL = "maxScroll";
        
        Actions(String name) {
            super(name);
        }
        
        @Override
        public void actionPerformed(ActionEvent actionEvent) {
            JScrollBar scrollBar = (JScrollBar)actionEvent.getSource();
            String name = this.getName();
            if (name == "positiveUnitIncrement") {
                this.scroll(scrollBar, 1, false);
            }
            else if (name == "positiveBlockIncrement") {
                this.scroll(scrollBar, 1, true);
            }
            else if (name == "negativeUnitIncrement") {
                this.scroll(scrollBar, -1, false);
            }
            else if (name == "negativeBlockIncrement") {
                this.scroll(scrollBar, -1, true);
            }
            else if (name == "minScroll") {
                this.scroll(scrollBar, 2, true);
            }
            else if (name == "maxScroll") {
                this.scroll(scrollBar, 3, true);
            }
        }
        
        private void scroll(JScrollBar scrollBar, int n, boolean b) {
            if (n == -1 || n == 1) {
                int n2;
                if (b) {
                    if (n == -1) {
                        n2 = -1 * scrollBar.getBlockIncrement(-1);
                    }
                    else {
                        n2 = scrollBar.getBlockIncrement(1);
                    }
                }
                else if (n == -1) {
                    n2 = -1 * scrollBar.getUnitIncrement(-1);
                }
                else {
                    n2 = scrollBar.getUnitIncrement(1);
                }
                scrollBar.setValue(scrollBar.getValue() + n2);
            }
            else if (n == 2) {
                scrollBar.setValue(scrollBar.getMinimum());
            }
            else if (n == 3) {
                scrollBar.setValue(scrollBar.getMaximum());
            }
        }
    }
    
    private class Handler implements FocusListener, PropertyChangeListener
    {
        @Override
        public void focusGained(FocusEvent focusEvent) {
            BasicScrollBarUI.this.scrollbar.repaint();
        }
        
        @Override
        public void focusLost(FocusEvent focusEvent) {
            BasicScrollBarUI.this.scrollbar.repaint();
        }
        
        @Override
        public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
            String propertyName = propertyChangeEvent.getPropertyName();
            if ("model" == propertyName) {
                BoundedRangeModel boundedRangeModel = (BoundedRangeModel)propertyChangeEvent.getOldValue();
                BoundedRangeModel boundedRangeModel2 = (BoundedRangeModel)propertyChangeEvent.getNewValue();
                boundedRangeModel.removeChangeListener(BasicScrollBarUI.this.modelListener);
                boundedRangeModel2.addChangeListener(BasicScrollBarUI.this.modelListener);
                BasicScrollBarUI.this.scrollBarValue = BasicScrollBarUI.this.scrollbar.getValue();
                BasicScrollBarUI.this.scrollbar.repaint();
                BasicScrollBarUI.this.scrollbar.revalidate();
            }
            else if ("orientation" == propertyName) {
                BasicScrollBarUI.access$700(BasicScrollBarUI.this);
            }
            else if ("componentOrientation" == propertyName) {
                BasicScrollBarUI.access$700(BasicScrollBarUI.this);
                SwingUtilities.replaceUIInputMap(BasicScrollBarUI.this.scrollbar, 0, BasicScrollBarUI.access$800(BasicScrollBarUI.this, 0));
            }
        }
    }
}
